@@ -35,7 +35,7 @@ use Exporter;
 #########################################################################
 # Setting global module variables
 #########################################################################
-$DeltaX::Database::VERSION = '3.3';				# Module version
+$DeltaX::Database::VERSION = '3.15';				# Module version
 
 #########################################################################
 # Procedure declaration
@@ -58,6 +58,7 @@ sub new {
 	$self->{trace}	= 0;
 	$self->{app}	= '';
 	$self->{host}	= '';
+        $self->{port}   = '';
 	$self->{codepage}	= '';
 	$self->{stat_type} = 'none';
 	$self->{stat_max_high} = 3;
@@ -1482,6 +1483,8 @@ sub get_source {
 	SWITCH: for ($driver) {
 		/Pg/		&& do {
 			$source = 'dbi:Pg:dbname=' . $source if $source !~ /dbi:Pg:dbname=/;
+			$source .= ';host=' . $self->{host} if $self->{host};
+			$source .= ';port=' . $self->{port} if $self->{port};
 			last SWITCH;};
 		/Oracle/	&& do {
 			$source = 'dbi:Oracle:' . $source if $source !~ /dbi:Oracle:/;
